@@ -5,7 +5,9 @@ import time
 import board
 import adafruit_is31fl3741
 
-is31 = adafruit_is31fl3741.IS31FL3741(board.I2C())
+i2c = board.I2C()  # uses board.SCL and board.SDA
+# i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller
+is31 = adafruit_is31fl3741.IS31FL3741(i2c)
 
 is31.set_led_scaling(0xFF)  # turn on LEDs all the way
 is31.global_current = 0xFF  # set current to max
